package com.flyfish.framework.validation.validators;

import com.flyfish.framework.validation.annotations.Phone;
import com.flyfish.framework.validation.enums.PhoneType;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import java.util.regex.Pattern;

/**
 * 判断是否是合法的电话号码
 * 会同时判定手机号或固话，固话拥有固定格式
 * 可以通过制定枚举，仅判断某一项
 * @author wangyu
 */
public class PhoneValidator implements ConstraintValidator<Phone, String> {

    private PhoneType type;

    private static final Pattern mobile = Pattern.compile("^1[3,5]\\d{9}||18[6,8,9]\\d{8}$");

    private static final Pattern tel = Pattern.compile("^[0][1-9]{2,3}-[0-9]{5,10}$");

    @Override
    public void initialize(Phone phone) {
        this.type = phone.type();
    }

    /**
     * 电话号码的校验逻辑
     * 支持类型拾取
     * @return 返回成功和失败
     */
    @Override
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if (type == PhoneType.ALL) {
            return isMobile(value) || isTel(value);
        }
        if (type == PhoneType.MOBILE) {
            return isMobile(value);
        }
        if (type == PhoneType.TEL) {
            return isTel(value);
        }
        return false;
    }

    private boolean isMobile(String value) {
        return mobile.matcher(value).matches();
    }

    private boolean isTel(String value) {
        return tel.matcher(value).matches();
    }
}
